@@ -338,7 +338,7 @@ sub wxpdf_get_pdfdocument_source {
 		my $datalength = 0;
 		my $updatesize = $content_size / 10;
 		my $totalupdate = 0;
-		open my $fh, '>', $self->wxpdf_source_file or die 'Could not open ' . $self->wxpdf_source_file;
+		open (my $fh, '>', $self->wxpdf_source_file) or die 'Could not open ' . $self->wxpdf_source_file;
 		binmode( $fh );
 		my $contentresponse = $ua->get( $self->wxpdf_source_url, ':content_cb' =>
 			sub {
@@ -355,7 +355,7 @@ sub wxpdf_get_pdfdocument_source {
 		close($fh);
 		if( !$contentresponse->is_success ) {
 			unlink $self->wxpdf_source_file;
-			my $msg = sprintf('Source Download Failed : %s : %s', $headeresponse->message, $self->wxpdf_source_url );
+			my $msg = sprintf('Source Download Failed : %s : %s', $contentresponse->message, $self->wxpdf_source_url );
 			$self->log_info("$msg\n");
 			die $msg;
 		}
