@@ -155,8 +155,11 @@ sub wxpdf_build_pdfdocument {
 	mkdir( $makedir , 0777 );
 	
 	chdir $makedir;
+	
+	my $target = $self->notes( 'pdfdoc-build-target' );
+	
 	$self->_run_command( \@cmd );
-	$self->_run_command( [ 'make' ] );
+	$self->_run_command( [ qq(make $target) ] );
 	chdir '../../';
 	$self->wxpdf_install_pdflibrary;
 	
